@@ -18,9 +18,6 @@ class ZipFileTest < MiniTest::Unit::TestCase
     end
 
     ::File.open(EMPTY_FILENAME, 'wb') { |file| file.write buffer.string }
-    # Not sure if the following line was just accidentally left in, but
-    # it's not related to the tests and breaks on windows
-    `cp #{EMPTY_FILENAME} ~/test.zip` unless Zip::RUNNING_ON_WINDOWS
 
     zfRead = ::Zip::File.new(EMPTY_FILENAME)
     assert_equal(comment, zfRead.comment)
@@ -89,6 +86,22 @@ class ZipFileTest < MiniTest::Unit::TestCase
     }
   end
 
+  def test_cleans_up_tempfiles_after_close
+    comment = "a short comment"
+
+    zf = ::Zip::File.new(EMPTY_FILENAME, ::Zip::File::CREATE)
+    zf.get_output_stream("myFile") do |os|
+      @tempfile_path = os.path
+      os.write "myFile contains just this"
+    end
+
+    assert_equal(true, File.exists?(@tempfile_path))
+
+    zf.close
+
+    assert_equal(false, File.exists?(@tempfile_path))
+  end
+
   def test_add
     srcFile = "test/data/file2.txt"
     entryName = "newEntryName.rb"
